@@ -1,21 +1,30 @@
 import collections
 import copy
+import datetime as dt
 import numbers
 import warnings
+from collections.abc import Iterable
 
 import numpy as np
 import pandas as pd
 from pint import Quantity
 from pint_pandas import PintArray, PintType
 
-from timeseriesx.validation.timestamp_index import (
-    index_is_datetime,
-    index_is_sorted,
-)
 from timeseriesx.base.base_time_series import BaseTimeSeries
 from timeseriesx.mixins.frequency import FrequencyMixin
 from timeseriesx.mixins.time_zone import TimeZoneMixin
 from timeseriesx.mixins.unit import UnitMixin
+from timeseriesx.validation.timestamp_index import (
+    index_is_datetime,
+    index_is_sorted,
+)
+
+
+class TimestampMismatchWarning(RuntimeWarning):
+    """
+    warning about implicit handling of mismatching timestamps
+    """
+    pass
 
 
 class TimestampSeries(UnitMixin, TimeZoneMixin, FrequencyMixin, BaseTimeSeries):
@@ -374,9 +383,9 @@ class TimestampSeries(UnitMixin, TimeZoneMixin, FrequencyMixin, BaseTimeSeries):
         self_timestamps = self.timestamps
         other_timestamps = other.timestamps
         if self.unit:
-            self_values = self._series.pint.to_base_units().values.data
+            self_values = list(self._series.pint.to_base_units().values)
         if other.unit:
-            other_values = other._series.pint.to_base_units().values.data
+            other_values = list(other._series.pint.to_base_units().values)
         if self.time_zone:
             tmp_self = copy.deepcopy(self)
             tmp_self.convert_time_zone('UTC')
@@ -386,8 +395,18 @@ class TimestampSeries(UnitMixin, TimeZoneMixin, FrequencyMixin, BaseTimeSeries):
             tmp_other.convert_time_zone('UTC')
             other_timestamps = tmp_other.timestamps
 
-        return self_timestamps == other_timestamps \
-               and (self_values == other_values).all()
+        return self_timestamps == other_timestamps and self_values == other_values
+
+    def __getitem__(self, item):
+        if isinstance(item, (slice, Iterable)):
+            new_ts = copy.deepcopy(self)
+            new_ts._series = new_ts._series[item]
+            return new_ts
+        else:
+            if isinstance(item, dt.datetime) and item.tzinfo is None \
+                    and self.time_zone is not None:
+                item = self.time_zone.localize(item)
+            return self._series[item]
 
     def __setitem__(self, key, value):
         raise NotImplementedError()
@@ -411,7 +430,8 @@ class TimestampSeries(UnitMixin, TimeZoneMixin, FrequencyMixin, BaseTimeSeries):
         if not self.unit == other.unit:
             raise ValueError("The time series have different units")
         if not self._series.index.equals(other._series.index):
-            warnings.warn("timestamps do not match, values are auto-filled")
+            warnings.warn("timestamps do not match, values are auto-filled",
+                          category=TimestampMismatchWarning)
         tmp_series._series = getattr(tmp_series._series, operation)(
             other._series, **kwargs)
         tmp_series.convert_time_zone(self.time_zone)
@@ -424,7 +444,8 @@ class TimestampSeries(UnitMixin, TimeZoneMixin, FrequencyMixin, BaseTimeSeries):
         if not all(map(lambda x: isinstance(x, numbers.Number), other)):
             raise ValueError("sequence contains non-numeric values")
         if not self._series.index.equals(other.index):
-            warnings.warn("timestamps do not match, values are auto-filled")
+            warnings.warn("timestamps do not match, values are auto-filled",
+                          category=RuntimeWarning)
         tmp_series._series = getattr(tmp_series._series, operation)(other, **kwargs)
         # enforce resulting TimestampSeries' time zone to be equal to initial
         # TimestampSeries (self)
